#
# spec file for package hitori
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hitori
Version:        3.36.0
Release:        lp152.1.2
Summary:        Original puzzle of Nikoli
License:        GPL-3.0-or-later
Group:          Amusements/Games/Logic
URL:            https://gitlab.gnome.org/GNOME/hitori
Source0:        https://download.gnome.org/sources/hitori/3.36/%{name}-%{version}.tar.xz

BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo) >= 1.4
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.15.0

%description
Hitori is played with a grid of squares or cells, and each cell contains a number.
The objective is to eliminate numbers by filling in the squares such that remaining cells do not
contain numbers that appear more than once in either a given row or column.

Filled-in cells cannot be horizontally or vertically adjacent, although they can be diagonally
adjacent. The remaining un-filled cells must form a single component connected horizontally
and vertically.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}
%suse_update_desktop_file org.gnome.Hitori
%fdupes %{buildroot}%{_prefix}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.gnome.Hitori.desktop
%{_datadir}/icons/hicolor/*/apps/org.gnome.Hitori*
%{_datadir}/glib-2.0/schemas/org.gnome.hitori.gschema.xml
%{_datadir}/metainfo/org.gnome.Hitori.appdata.xml

%files lang -f %{name}.lang

%changelog
* Wed Mar 11 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + No changes, stable version update only.
* Mon Mar  2 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.0:
  + Bugs fixed:
  - Snap: Update yaml to use GNOME extension.
  - Window: Allow reaching smaller sizes.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Sep  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
- Changes from version 3.33.0:
  + Remember window size and position.
  + Support localised (non-Arabic) digits on the game board.
  + Add keyboard shortcuts dialogue and improve keyboard shortcuts
    and mnemonics.
  + Bugs fixed: bgo#732788, bgo#735330, glgo#GNOME/hitori#13,
    glgo#GNOME/hitori!5, glgo#GNOME/hitori!7, glgo#GNOME/hitori!15,
    glgo#GNOME/hitori!21, glgo#GNOME/hitori!22,
    glgo#GNOME/hitori!23.
* Thu Aug 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Mon Mar  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Add high-resolution icon.
  + Bugs fixed: glgo#GNOME/hitori#6, glgo#GNOME/hitori!16,
    glgo#GNOME/hitori!17, glgo#GNOME/hitori!19.
  + Updated translations.
- Add itstool BuildRequires: New dependency.
- Add fdupes BuildRequires and macro, remove duplicate files.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.0:
  + Migrated to Meson.
  + Bugs fixed:
  - Retire app menu.
  - Migrate to Meson.
  - Use G_DECLARE_FINAL_TYPE() to declare type.
  - snap: Add snap build configuration.
  - Port README to Markdown.
  - docs: Reformat NEWS to be valid Markdown.
  + Updated translations.
- Switch to meson build system, add meson BuildRequires and macros.
- Stop handling icon_theme_cache_post(un),
  desktop_database_post(un) and glib2_gsettings_schema_post(un) in
  post(un) and drop glib2_gsettings_schema_requires.
- Drop yelp-tools and hicolor-icon-theme BuildRequires: No longer
  needed.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Oct  5 2017 zaitor@opensuse.org
- Update to version 3.22.4:
  + Updated translations.
* Fri May 12 2017 zaitor@opensuse.org
- Update to version 3.22.3:
  + Minor rendering improvements (bgo#732776).
  + Add flatpak manifests for nightly builds.
  + Drop use of deprecated GTK+ API (no dependency change).
  + Updated translations.
* Mon Mar  6 2017 zaitor@opensuse.org
- Update to version 3.22.2:
  + Add more build-time checks (this adds an optional build-time
    dependency on desktop-file-validate).
  + Updated translations.
- Add explicit desktop-file-utils BuildRequires, it is already
  pulled in for us, but since upstream now checks for it, we should
  list it.
* Tue Feb 14 2017 zaitor@opensuse.org
- Update to version 3.22.1:
  + Port from intltool to gettext (this drops the intltool
    dependency).
  + Add various build-time checks (this adds an optional build-time
    dependency on xmllint).
  + Updated translations.
- Drop intltool BuildRequires following upstreams port.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Various AppData fixes.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Various AppData fixes.
  + Fix a GTK+ warning about styling with newer GTK+ versions.
  + Updated translations.
- Drop hitori-old-icon-name.patch: fixed upstream.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.19.1:
  + Rename icon, desktop and appdata files to use
    ‘org.gnome.Hitori’ prefix.
  + Remove dependency on gnome-common in favour of autoconf-archive
    (or m4-common).
- Add hitori-old-icon-name.patch: Fix references to old icon names.
* Tue Nov 24 2015 dimstar@opensuse.org
- Update to version 3.16.2:
  + Fix build error with Clang.
  + Updated translations.
* Sat May  2 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Updated symbolic icon.
* Tue Apr 14 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Port to GResource for UI and CSS.
  + Minor menu tweaks.
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.14.3:
  + Updated translations.
* Tue Dec 16 2014 zaitor@opensuse.org
- Update to version 3.14.2.1:
  + Revert string freeze break.
* Sun Dec 14 2014 badshah400@gmail.com
- Update to version 3.14.2:
  + data: Add <summary> element to the AppData file.
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Mon Sep 22 2014 dimstar@opensuse.org
- Update to version 3.14.0.1:
  + Re-release: autoreconf with up-to-date appstream-glib; fixes
    install location for hitori.appdata.xml.
* Mon Sep 22 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep 16 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Minor UI and translation updates.
  + Minor build system updates.
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Follow guidelines for including license info in help.
  + Updated translations.
* Fri Jul 25 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Updated translations.
- Add glib_schema macros, as we now install a schema.xml - file.
* Wed Jul  9 2014 zaitor@opensuse.org
- Update to version 0.4.5:
  + Minor fixes to the board rendering and timer.
- Changes from version 0.4.4:
  + Fix various small memory leaks.
  + Fix behaviour of the redo stack.
  + Updated translations.
* Sun May  4 2014 zaitor@opensuse.org
- Update to version 0.4.3:
  + Updated translations.
- Changes from version 0.4.2:
  + Add an AppData file.
  + Updated translations.
- Changes from version 0.4.1:
  + Fix timer pausing on winning a game.
  + Updated translations.
* Wed Mar  6 2013 dimstar@opensuse.org
- Initial package, version 0.4.0.
